@@ -32,6 +32,10 @@
 #include "searchcallarray.h"
 #include "tlf_curses.h"
 #include "ui_utils.h"
+#include "getctydata.h"
+#include "dxcc.h"
+#include "initial_exchange.h"
+#include "bands.h"
 
 #define TOLERANCE 100 		/* spots with a QRG +/-TOLERANCE
 				   will be counted as the same QRG */
@@ -42,39 +46,6 @@
 				/* 3 space before and 1 after call */
 
 
-unsigned int bandcorner[NBANDS][2] =
-{{ 1800000, 2000000 },	// band bottom, band top
- { 3500000, 4000000 },
- { 7000000, 7300000 },
- { 10100000, 10150000 },
- { 14000000, 14350000 },
- { 18068000, 18168000 },
- { 21000000, 21450000 },
- { 24890000, 24990000 },
- { 28000000, 29700000 }};
-
-unsigned int cwcorner[NBANDS] =
-{ 1838000,
-  3580000,
-  7040000,
-  10140000,
-  14070000,
-  18095000,
-  21070000,
-  24915000,
-  28070000};
-
-unsigned int ssbcorner[NBANDS] =
-{ 1840000,
-  3600000,
-  7040000,
- 10150000,
- 14100000,
- 18120000,
- 21150000,
- 24930000,
- 28300000 };
-
 pthread_mutex_t bm_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 /** \brief sorted list of all recent DX spots
@@ -91,7 +62,8 @@ bm_config_t bm_config = {
     1,  /* show all mode */
     1,  /* show dupes */
     1,	/* skip dupes during grab */
-    900	/* default livetime */
+    900,/* default livetime */
+    0  /* DO NOT show ONLY multipliers */
 };
 short	bm_initialized = 0;
 
@@ -102,8 +74,9 @@ extern int trxmode;
 extern char thisnode;
 extern struct worked_t worked[];
 extern int contest;
+extern char whichcontest[];
 
-char *qtc_format(char * call);
+char *qtc_format(char *call);
 
 gint cmp_freq(spot *a, spot *b);
 
@@ -112,13 +85,13 @@ gint cmp_freq(spot *a, spot *b);
  */
 void bmdata_write_file() {
 
-    FILE * fp;
-    spot * sp;
+    FILE *fp;
+    spot *sp;
     GList *found;
     struct timeval tv;
 
     if ((fp = fopen(".bmdata.dat", "w")) == NULL) {
-	attron(modify_attr(COLOR_PAIR(CB_DUPE)|A_BOLD));
+	attron(modify_attr(COLOR_PAIR(CB_DUPE) | A_BOLD));
 	mvprintw(13, 29, "can't open bandmap data file!");
 	refreshp();
 	return;
@@ -126,19 +99,20 @@ void bmdata_write_file() {
 
     gettimeofday(&tv, NULL);
 
-    pthread_mutex_lock( &bm_mutex );
+    pthread_mutex_lock(&bm_mutex);
 
     found = allspots;
     fprintf(fp, "%d\n", (int)tv.tv_sec);
     while (found != NULL) {
 	sp = found->data;
-	fprintf(fp, "%s;%d;%d;%d;%c;%u;%d\n",
+	fprintf(fp, "%s;%d;%d;%d;%c;%u;%d;%d;%d;%s\n",
 		sp->call, sp->freq, sp->mode, sp->band,
-		sp->node, (int)sp->timeout, sp->dupe);
+		sp->node, (int)sp->timeout, sp->dupe, sp->cqzone,
+		sp->ctynr, g_strchomp(sp->pfx));
 	found = found->next;
     }
 
-    pthread_mutex_unlock( &bm_mutex );
+    pthread_mutex_unlock(&bm_mutex);
 
     fclose(fp);
 }
@@ -147,14 +121,14 @@ void bmdata_write_file() {
  * read bandmap spots from file, put them to allspots list
  */
 void bmdata_read_file() {
-    FILE * fp;
+    FILE *fp;
     struct timeval tv;
     int timediff, last_bm_save_time, fc;
     char line[50], *token;
     static int bmdata_parsed = 0;
 
     if ((fp = fopen(".bmdata.dat", "r")) != NULL && bmdata_parsed == 0) {
-        bmdata_parsed = 1;
+	bmdata_parsed = 1;
 	timediff = 0;
 	if (fgets(line, 50, fp)) {
 	    sscanf(line, "%d", &last_bm_save_time);
@@ -164,33 +138,38 @@ void bmdata_read_file() {
 		timediff = 0;
 
 	    while (fgets(line, 50, fp)) {
-	        spot *entry = g_new0(spot, 1);
+		spot *entry = g_new0(spot, 1);
 		fc = 0;
-		token = strtok (line, ";");
-		while (token != NULL)
-		{
-		    switch(fc) {
+		token = strtok(line, ";");
+		while (token != NULL) {
+		    switch (fc) {
 			case 0:		entry -> call = g_strdup(token);
-					break;
+			    break;
 			case 1:		sscanf(token, "%d", &entry->freq);
-					break;
+			    break;
 			case 2:		sscanf(token, "%hhd", &entry->mode);
-					break;
+			    break;
 			case 3:		sscanf(token, "%hd", &entry->band);
-					break;
+			    break;
 			case 4:		sscanf(token, "%c", &entry->node);
-					break;
+			    break;
 			case 5:		sscanf(token, "%u", &entry->timeout);
-					break;
+			    break;
 			case 6:		sscanf(token, "%hhd", &entry->dupe);
-					break;
+			    break;
+			case 7:		sscanf(token, "%u", &entry->cqzone);
+			    break;
+			case 8:		sscanf(token, "%u", &entry->ctynr);
+			    break;
+			case 9:		entry->pfx = g_strdup(token);
+			    break;
 		    }
 		    fc++;
-		    token = strtok (NULL, ";");
+		    token = strtok(NULL, ";");
 		}
 		if (entry->timeout > timediff) {
 		    entry->timeout -= timediff;	/* remaining time */
-		    allspots = g_list_insert_sorted( allspots, entry, (GCompareFunc)cmp_freq);
+		    allspots = g_list_insert_sorted(allspots, entry, (GCompareFunc)cmp_freq);
 		} else {
 		    g_free(entry);
 		}
@@ -206,36 +185,19 @@ void bmdata_read_file() {
  */
 void bm_init() {
 
-    pthread_mutex_lock( &bm_mutex );
+    pthread_mutex_lock(&bm_mutex);
 
-    init_pair (CB_NEW, COLOR_CYAN, COLOR_WHITE);
-    init_pair (CB_NORMAL, COLOR_BLUE, COLOR_WHITE);
-    init_pair (CB_DUPE, COLOR_BLACK, COLOR_WHITE);
-    init_pair (CB_OLD, COLOR_YELLOW, COLOR_WHITE);
-    init_pair (CB_MULTI, COLOR_WHITE, COLOR_BLUE);
+    init_pair(CB_NEW, COLOR_CYAN, COLOR_WHITE);
+    init_pair(CB_NORMAL, COLOR_BLUE, COLOR_WHITE);
+    init_pair(CB_DUPE, COLOR_BLACK, COLOR_WHITE);
+    init_pair(CB_OLD, COLOR_YELLOW, COLOR_WHITE);
+    init_pair(CB_MULTI, COLOR_WHITE, COLOR_BLUE);
 
-    spots = g_ptr_array_sized_new( 128 );
+    spots = g_ptr_array_sized_new(128);
 
     bmdata_read_file();
 
-    pthread_mutex_unlock( &bm_mutex );
-}
-
-
-/** \brief convert frequency to bandnumber
- *
- * \return	bandnumber or -1 if not in any band
- */
-int freq2band(unsigned int freq) {
-    int i;
-
-    for (i = 0; i < NBANDS; i++) {
-	if (freq >= (unsigned int)bandcorner[i][0] &&
-		    freq <= (unsigned int)bandcorner[i][1])
-	    return i;	/* in actual band */
-    }
-
-    return -1;		/* not in any band */
+    pthread_mutex_unlock(&bm_mutex);
 }
 
 
@@ -247,7 +209,7 @@ int freq2mode(int freq, int band) {
     if (freq <= cwcorner[band])
 	return CWMODE;
     else if (freq < ssbcorner[band])
-    	return DIGIMODE;
+	return DIGIMODE;
     else
 	return SSBMODE;
 }
@@ -260,6 +222,7 @@ int freq2mode(int freq, int band) {
  * if so split it into pieces and insert in spot list */
 void bm_add(char *s) {
     char *line;
+    char *call;
     char node = ' ';
 
     line = g_strdup(s);
@@ -268,16 +231,21 @@ void bm_add(char *s) {
 	return;
     }
 
+    if ((call = strtok(line + 26, " \t")) == NULL) {
+	g_free(line);
+	return;
+    }
+
     if (strncmp(line + 6, "TLF-", 4) == 0)
 	node = line[10];		/* get sending node id */
 
-    bandmap_addspot (strtok(line+26, " \t") , (unsigned int)(atof(line+16)*1000) , node);
-    g_free (line);
+    bandmap_addspot(call, (unsigned int)(atof(line + 16) * 1000), node);
+    g_free(line);
 }
 
 
 /* compare functions to search in list */
-gint	cmp_call (spot* ldata, char *call) {
+gint	cmp_call(spot *ldata, char *call) {
 
     return g_strcmp0(ldata->call, call);
 }
@@ -296,32 +264,38 @@ gint	cmp_freq(spot *a, spot *b) {
  * \param freq 		on which frequency heard
  * \param node		reporting node
  */
-void bandmap_addspot( char *call, unsigned int freq, char node) {
-/* - if a spot on that band and mode is already in list replace old entry
- *   with new one and set timeout to SPOT_NEW,
- *   otherwise add it to the list as new
- * - if other call on same frequency (with some TOLERANCE) replace it and set
- *   timeout to SPOT_NEW
- * - all frequencies from cluster are rounded to 100 Hz,
- *   remember all other frequencies exactly
- *   but display only rounded to 100 Hz - sort exact
- */
+void bandmap_addspot(char *call, unsigned int freq, char node) {
+    /* - if a spot on that band and mode is already in list replace old entry
+     *   with new one and set timeout to SPOT_NEW,
+     *   otherwise add it to the list as new
+     * - if other call on same frequency (with some TOLERANCE) replace it and set
+     *   timeout to SPOT_NEW
+     * - all frequencies from cluster are rounded to 100 Hz,
+     *   remember all other frequencies exactly
+     *   but display only rounded to 100 Hz - sort exact
+     */
     GList *found;
     int band;
     char mode;
+    dxcc_data *dxccdata;
+    int dxccindex;
+    int wi;
+    char *lastexch;
+    extern struct ie_list *main_ie_list;
+    struct ie_list *current_ie;
 
     /* add only HF spots */
     if (freq > 30000000)
 	return;
 
     band = freq2band(freq);
-    if (band < 0)	/* no ham band */
+    if (band == BANDINDEX_OOB)  /* no ham band */
 	return;
 
     mode = freq2mode(freq, band);
 
     /* acquire bandmap mutex */
-    pthread_mutex_lock( &bm_mutex );
+    pthread_mutex_lock(&bm_mutex);
 
     /* look if call is already on list in that mode and band */
     /* each call is allowed in every combination of band and mode
@@ -333,7 +307,7 @@ void bandmap_addspot( char *call, unsigned int freq, char node) {
 	/* if same band and mode -> found spot already in list */
 	if (((spot *)found->data)->band == band &&
 		((spot *)found->data)->mode == mode)
-    	    break;
+	    break;
 
 	found = g_list_find_custom(found->next, call, (GCompareFunc)cmp_call);
     }
@@ -343,16 +317,15 @@ void bandmap_addspot( char *call, unsigned int freq, char node) {
      *   		if freq has changed enough sort list anew by freq
      */
     if (found) {
-    	((spot*)found->data)->timeout = SPOT_NEW;
-	((spot*)found->data)->node = node;
-	if (abs(((spot*)found->data)->freq - freq) > TOLERANCE) {
-	    ((spot*)found->data)->freq = freq;
+	((spot *)found->data)->timeout = SPOT_NEW;
+	((spot *)found->data)->node = node;
+	if (abs(((spot *)found->data)->freq - freq) > TOLERANCE) {
+	    ((spot *)found->data)->freq = freq;
 	    allspots = g_list_sort(allspots, (GCompareFunc)cmp_freq);
 	}
-    }
-    else {
-    /* if not in list already -> prepare new entry and
-     * insert in list at correct freq */
+    } else {
+	/* if not in list already -> prepare new entry and
+	 * insert in list at correct freq */
 	spot *entry = g_new(spot, 1);
 	entry -> call = g_strdup(call);
 	entry -> freq = freq;
@@ -362,7 +335,42 @@ void bandmap_addspot( char *call, unsigned int freq, char node) {
 	entry -> timeout = SPOT_NEW;
 	entry -> dupe = 0;	/* Dupe will be determined later. */
 
-	allspots = g_list_insert_sorted( allspots, entry, (GCompareFunc)cmp_freq);
+	lastexch = NULL;
+	dxccindex = getctynr(entry->call);
+	if (cqww == 1) {
+	    // check if the callsign exists in worked list
+	    wi = searchcallarray(call);
+	    if (wi >= 0) {
+		lastexch = g_strdup(worked[wi].exchange);
+	    }
+
+	    if (lastexch == NULL && main_ie_list != NULL) {
+		current_ie = main_ie_list;
+
+		while (current_ie) {
+		    if (strcmp(call, current_ie->call) == 0) {
+			lastexch = g_strdup(current_ie->exchange);
+			break;
+		    }
+		    current_ie = current_ie->next;
+		}
+	    }
+	}
+	if (dxccindex > 0) {
+	    dxccdata = dxcc_by_index(dxccindex);
+	    entry -> cqzone = dxccdata->cq;
+	    if (lastexch != NULL) {
+		entry -> cqzone = atoi(lastexch);
+		g_free(lastexch);
+	    }
+	    entry -> ctynr = dxccindex;
+	    entry -> pfx = g_strdup(dxccdata->pfx);
+	} else {
+	    entry -> cqzone = 0;
+	    entry -> ctynr = 0;
+	    entry -> pfx = g_strdup("");
+	}
+	allspots = g_list_insert_sorted(allspots, entry, (GCompareFunc)cmp_freq);
 	/* lookup where it is */
 	found = g_list_find(allspots, entry);
     }
@@ -370,36 +378,38 @@ void bandmap_addspot( char *call, unsigned int freq, char node) {
     /* check that spot is unique on freq +/- TOLERANCE Hz,
      * drop other entries if needed */
     if (found->prev &&
-	(abs(((spot*)(found->prev)->data)->freq - freq) < TOLERANCE)) {
+	    (abs(((spot *)(found->prev)->data)->freq - freq) < TOLERANCE)) {
 	spot *olddata;
 	olddata = found->prev->data;
 	allspots = g_list_remove_link(allspots, found->prev);
-	g_free (olddata->call);
-	g_free (olddata);
+	g_free(olddata->call);
+	g_free(olddata->pfx);
+	g_free(olddata);
     }
     if (found->next &&
-	(abs(((spot*)(found->next)->data)->freq - freq) < TOLERANCE)) {
+	    (abs(((spot *)(found->next)->data)->freq - freq) < TOLERANCE)) {
 	spot *olddata;
 	olddata = found->next->data;
 	allspots = g_list_remove_link(allspots, found->next);
-	g_free (olddata->call);
-	g_free (olddata);
+	g_free(olddata->call);
+	g_free(olddata->pfx);
+	g_free(olddata);
     }
 
 
-    pthread_mutex_unlock( &bm_mutex );
+    pthread_mutex_unlock(&bm_mutex);
 }
 
 
 void bandmap_age() {
-/*
- * go through all entries
- *   + decrement timeout
- *   + set state to new, normal, aged or dead
- *   + if dead -> drop it from collection
- */
+    /*
+     * go through all entries
+     *   + decrement timeout
+     *   + set state to new, normal, aged or dead
+     *   + if dead -> drop it from collection
+     */
 
-    pthread_mutex_lock( &bm_mutex );
+    pthread_mutex_lock(&bm_mutex);
 
     GList *list = allspots;
 
@@ -411,24 +421,34 @@ void bandmap_age() {
 	    data->timeout--;
 	}
 	if (data->timeout == 0) {
-	    allspots = g_list_remove_link( allspots, temp);
-	    g_free (data->call);
-	    g_free (data);
+	    allspots = g_list_remove_link(allspots, temp);
+	    g_free(data->call);
+	    g_free(data->pfx);
+	    g_free(data);
 	}
     }
 
-    pthread_mutex_unlock( &bm_mutex );
+    pthread_mutex_unlock(&bm_mutex);
 }
 
 
-int bm_ismulti( char * call) {
+int bm_ismulti(char *call, spot *data, int band) {
+
+    if (data != NULL && data->cqzone > 0 && data->ctynr > 0) {
+	if (cqww == 1) {
+	    if ((zones[data->cqzone] & inxes[band]) == 0
+		    || (countries[data->ctynr] & inxes[band]) == 0) {
+		return 1;
+	    }
+	}
+    }
     return 0;
 }
 
 
 /** \todo should check band AND mode if already worked.... */
 
-int bm_isdupe( char *call, int band ) {
+int bm_isdupe(char *call, int band) {
     int found = -1;
     struct t_qtc_store_obj *qtc_obj;
 
@@ -442,7 +462,7 @@ int bm_isdupe( char *call, int band ) {
 	return 0;
 
     if (qtcdirection > 0) {
-        qtc_obj = qtc_get(call);
+	qtc_obj = qtc_get(call);
 	if (qtc_obj->total > 0 && qtc_obj->total < 10) {
 	    return 0;
 	}
@@ -452,8 +472,7 @@ int bm_isdupe( char *call, int band ) {
     }
     if (worked[found].band & inxes[band]) {
 	return 1;
-    }
-    else {
+    } else {
 	return 0;
     }
 }
@@ -463,33 +482,34 @@ void bm_show_info() {
 
     int curx, cury;
 
-    getyx( stdscr, cury, curx);		/* remember cursor */
+    getyx(stdscr, cury, curx);		/* remember cursor */
 
     /* show info field on the right */
-    attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
-    move(14,66);
-    vline(ACS_VLINE,10);
+    attrset(COLOR_PAIR(CB_DUPE) | A_BOLD);
+    move(14, 66);
+    vline(ACS_VLINE, 10);
 
-    mvprintw (19, 68, "bands: %s", bm_config.allband ? "all" : "own");
-    mvprintw (20,68, "modes: %s", bm_config.allmode ? "all" : "own");
-    mvprintw (21,68, "dupes: %s", bm_config.showdupes ? "yes" : "no");
+    mvprintw(18, 68, "bands: %s", bm_config.allband ? "all" : "own");
+    mvprintw(19, 68, "modes: %s", bm_config.allmode ? "all" : "own");
+    mvprintw(20, 68, "dupes: %s", bm_config.showdupes ? "yes" : "no");
+    mvprintw(21, 68, "onl.ml: %s", bm_config.onlymults ? "yes" : "no");
 
-    attrset(COLOR_PAIR(CB_NEW)|A_STANDOUT);
-    mvprintw( 22 ,69, "MULTI");
+    attrset(COLOR_PAIR(CB_NEW) | A_STANDOUT);
+    mvprintw(22, 69, "MULTI");
 
-    attrset(COLOR_PAIR(CB_NEW)|A_BOLD);
-    printw( " NEW");
+    attrset(COLOR_PAIR(CB_NEW) | A_BOLD);
+    printw(" NEW");
 
     attrset(COLOR_PAIR(CB_NORMAL));
-    mvprintw( 23,67, "SPOT");
+    mvprintw(23, 67, "SPOT");
 
     attrset(COLOR_PAIR(CB_OLD));
-    printw( " OLD");
+    printw(" OLD");
 
-    attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
-    printw( " dupe");
+    attrset(COLOR_PAIR(CB_DUPE) | A_BOLD);
+    printw(" dupe");
 
-    attroff (A_BOLD|A_STANDOUT);
+    attroff(A_BOLD | A_STANDOUT);
 
     move(cury, curx);			/* reset cursor */
 }
@@ -503,7 +523,7 @@ void bm_show_info() {
  * - worked	small caps */
 void colorize_spot(spot *data) {
     if (data -> timeout > SPOT_NORMAL)
-	attrset(COLOR_PAIR(CB_NEW)|A_BOLD);
+	attrset(COLOR_PAIR(CB_NEW) | A_BOLD);
 
     else if (data -> timeout > SPOT_OLD)
 	attrset(COLOR_PAIR(CB_NORMAL));
@@ -511,12 +531,14 @@ void colorize_spot(spot *data) {
     else
 	attrset(COLOR_PAIR(CB_OLD));
 
-    if (bm_ismulti(data->call))
+    if (bm_ismulti(NULL, data, data->band)) {
+	attrset(COLOR_PAIR(CB_NEW) | A_STANDOUT);
 	attron(A_STANDOUT);
+    }
 
-    if (data->dupe && bm_config.showdupes) {
-        attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
-        attroff(A_STANDOUT);
+    else if (data->dupe && bm_config.showdupes) {
+	attrset(COLOR_PAIR(CB_DUPE) | A_BOLD);
+	attroff(A_STANDOUT);
     }
 }
 
@@ -530,14 +552,13 @@ char *format_spot(spot *data) {
 
     if (qtcdirection > 0) {
 	temp = qtc_format(data->call);
-    }
-    else
+    } else
 	temp = g_strdup(data->call);
 
     if (data->dupe && bm_config.showdupes) {
-       temp2 = temp;
-       temp = g_ascii_strdown(temp2, -1);
-       g_free(temp2);
+	temp2 = temp;
+	temp = g_ascii_strdown(temp2, -1);
+	g_free(temp2);
     }
     return temp;
 }
@@ -546,14 +567,14 @@ char *format_spot(spot *data) {
 /* helper function for bandmap display
  * shows formatted spot on actual cursor position
  */
-void show_spot(spot * data) {
-    attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
-    printw ("%7.1f %c ", (float)(data->freq/1000.),
-	    (data->node == thisnode ? '*' : data->node));
+void show_spot(spot *data) {
+    attrset(COLOR_PAIR(CB_DUPE) | A_BOLD);
+    printw("%7.1f %c ", (float)(data->freq / 1000.),
+	   (data->node == thisnode ? '*' : data->node));
 
     char *temp = format_spot(data);
     colorize_spot(data);
-    printw ("%-12s", temp);
+    printw("%-12s", temp);
     g_free(temp);
 }
 
@@ -561,13 +582,13 @@ void show_spot(spot * data) {
 /* helper function for bandmap display
  * shows spot on actual working frequency
  */
-void show_spot_on_qrg(spot * data) {
+void show_spot_on_qrg(spot *data) {
 
-    printw ("%7.1f %c ", (data->freq/1000.),
-	    (data->node == thisnode ? '*' : data->node));
+    printw("%7.1f %c ", (data->freq / 1000.),
+	   (data->node == thisnode ? '*' : data->node));
 
     char *temp = format_spot(data);
-    printw ("%-12s", temp);
+    printw("%-12s", temp);
     g_free(temp);
 }
 
@@ -575,7 +596,7 @@ void show_spot_on_qrg(spot * data) {
 /* helper function for bandmap display
  * advance to next spot position
  */
-void next_spot_position (int *y, int *x) {
+void next_spot_position(int *y, int *x) {
     *y += 1;
     if (*y == 24) {
 	*y = 14;
@@ -590,8 +611,7 @@ void next_spot_position (int *y, int *x) {
  * Otherwise calculate center frequency from band and mode
  * as middle value of the band/mode corners.
  */
-float bm_get_center(band, mode)
-{
+float bm_get_center(int band, int mode) {
     float centerfrequency;
 
     if (trx_control)
@@ -610,45 +630,45 @@ float bm_get_center(band, mode)
 
 
 void bandmap_show() {
-/*
- * display depending on filter state
- * - all bands on/off
- * - all mode  on/off
- * - dupes     on/off
- *
- * If more entries to show than room in window, show around current frequency
- *
- * mark entries according to age, source and worked state. Mark new multis
- * - new 	brigth blue
- * - normal	blue
- * - aged	black
- * - worked	small caps
- * - new multi	underlined
- * - self announced stations
- *   		small preceeding letter for reporting station
- *
- * maybe show own frequency as dashline in other color
- * (maybee green highlighted)
- * - highligth actual spot if near its frequency
- *
- * Allow selection of one of the spots (switches to S&P)
- * - Ctrl-G as known
- * - '.' and cursor plus 'Enter' \Todo
- * - Test mouseclick..           \Todo
- *
- * '.' goes into map, shows help line above and supports
- * - cursormovement
- * - 'ESC' leaves mode
- * - 'Enter' selects spot
- * - 'B', 'D', 'M' switches filtering for band, dupes and mode on or off.
- */
+    /*
+     * display depending on filter state
+     * - all bands on/off
+     * - all mode  on/off
+     * - dupes     on/off
+     *
+     * If more entries to show than room in window, show around current frequency
+     *
+     * mark entries according to age, source and worked state. Mark new multis
+     * - new 	brigth blue
+     * - normal	blue
+     * - aged	black
+     * - worked	small caps
+     * - new multi	underlined
+     * - self announced stations
+     *   		small preceeding letter for reporting station
+     *
+     * maybe show own frequency as dashline in other color
+     * (maybee green highlighted)
+     * - highligth actual spot if near its frequency
+     *
+     * Allow selection of one of the spots (switches to S&P)
+     * - Ctrl-G as known
+     * - '.' and cursor plus 'Enter' \Todo
+     * - Test mouseclick..           \Todo
+     *
+     * '.' goes into map, shows help line above and supports
+     * - cursormovement
+     * - 'ESC' leaves mode
+     * - 'Enter' selects spot
+     * - 'B', 'D', 'M', 'O' switches filtering for band, dupes, mode and multiPlier on or off.
+     */
 
     GList *list;
     spot *data;
     int curx, cury;
     int bm_x, bm_y;
-    int i,j;
-    short dupe;
+    int i, j;
+    short dupe, multi;
     float centerfrequency;
 
     if (!bm_initialized) {
@@ -663,15 +683,15 @@ void bandmap_show() {
      * furthermore do not allow call lookup as long as
      * filtered spot array is build anew */
 
-    pthread_mutex_lock( &bm_mutex );
+    pthread_mutex_lock(&bm_mutex);
 
     /* make array of spots to display
      * filter spotlist according to settings */
 
     if (spots)
-	g_ptr_array_free( spots, TRUE);		/* free array */
+	g_ptr_array_free(spots, TRUE);		/* free array */
 
-    spots = g_ptr_array_sized_new( 128 );	/* allocate new one */
+    spots = g_ptr_array_sized_new(128);	/* allocate new one */
 
     list = allspots;
 
@@ -682,43 +702,45 @@ void bandmap_show() {
 	 * actual one than add it to the filtered 'spot' array
 	 * drop spots on WARC bands if in contest mode
 	 */
-
+	multi = bm_ismulti(NULL, data, data->band);
 	dupe = bm_isdupe(data->call, data->band);
-	if (    (!contest || !IsWarcIndex(data->band))         &&
+
+	if ((!contest || !IsWarcIndex(data->band))         &&
 		(bm_config.allband || (data->band == bandinx)) &&
 		(bm_config.allmode || (data->mode == trxmode)) &&
-		(bm_config.showdupes || !dupe)) {
+		(bm_config.showdupes || !dupe) &&
+		(! bm_config.onlymults || multi)) {
 
 	    data -> dupe = dupe;
-	    g_ptr_array_add( spots, data );
+	    g_ptr_array_add(spots, data);
 	}
 
 	list = list->next;
     }
 
-    pthread_mutex_unlock( &bm_mutex );
+    pthread_mutex_unlock(&bm_mutex);
 
 
     /* afterwards display filtered list around own QRG +/- some offest
      * (offset gets reset if we change frequency */
 
-    getyx( stdscr, cury, curx);		/* remember cursor */
+    getyx(stdscr, cury, curx);		/* remember cursor */
 
     /* start in line 14, column 0 */
     bm_y = 14;
     bm_x = 0;
 
     /* clear space for bandmap */
-    attrset(COLOR_PAIR(CB_DUPE)|A_BOLD);
+    attrset(COLOR_PAIR(CB_DUPE) | A_BOLD);
 
-    move(bm_y,0);			/* do not overwrite # frequency */
+    move(bm_y, 0);			/* do not overwrite # frequency */
     for (j = 0; j < 67; j++)
 	addch(' ');
 
     for (i = bm_y + 1; i < bm_y + 10; i++) {
-	move (i,0);
+	move(i, 0);
 	for (j = 0; j < 80; j++)
-	    addch (' ');
+	    addch(' ');
     }
 
     /* show info text */
@@ -740,9 +762,9 @@ void bandmap_show() {
 
     /* calc number of spots below your current QRG */
     for (i = 0; i < spots->len; i++) {
-	data = g_ptr_array_index( spots, i );
+	data = g_ptr_array_index(spots, i);
 
-	if (data->freq <= (centerfrequency*1000 - TOLERANCE))
+	if (data->freq <= (centerfrequency * 1000 - TOLERANCE))
 	    below_qrg++;
 	else
 	    break;
@@ -750,9 +772,9 @@ void bandmap_show() {
 
     /* check if current QRG is on a spot */
     if (below_qrg < spots->len) {
-	data = g_ptr_array_index( spots, below_qrg );
+	data = g_ptr_array_index(spots, below_qrg);
 
-	if (!(data->freq > centerfrequency*1000 + TOLERANCE))
+	if (!(data->freq > centerfrequency * 1000 + TOLERANCE))
 	    on_qrg = 1;
     }
 
@@ -763,17 +785,16 @@ void bandmap_show() {
 
 	if (above_qrg < 14) {
 	    max_below = 30 - above_qrg - 1;
-	}
-	else
+	} else
 	    max_below = 15;
 
-	startindex = (below_qrg < max_below)? 0 : (below_qrg - max_below);
+	startindex = (below_qrg < max_below) ? 0 : (below_qrg - max_below);
     }
 
     /* calculate the index+1 of the last spot to show */
     stopindex  = (spots->len < startindex + 30 - (1 - on_qrg))
-	? spots->len
-	: (startindex + 30 - (1 - on_qrg));
+		 ? spots->len
+		 : (startindex + 30 - (1 - on_qrg));
 
     /* correct calculations if we have no rig frequency to show */
     if (trx_control == 0) {
@@ -787,36 +808,33 @@ void bandmap_show() {
     }
 
     /* show spots below QRG */
-    for (i = startindex; i < below_qrg; i++)
-    {
-	move (bm_y, bm_x);
-	show_spot(g_ptr_array_index( spots, i ));
+    for (i = startindex; i < below_qrg; i++) {
+	move(bm_y, bm_x);
+	show_spot(g_ptr_array_index(spots, i));
 	next_spot_position(&bm_y, &bm_x);
     }
 
     /* show highlighted frequency marker or spot on QRG if rig control
      * is active */
     if (trx_control != 0) {
-	move (bm_y, bm_x);
+	move(bm_y, bm_x);
 	attrset(COLOR_PAIR(C_HEADER) | A_STANDOUT);
 	if (!on_qrg) {
-	    printw ("%7.1f   %s", centerfrequency,  "============");
-	}
-	else {
-	    show_spot_on_qrg(g_ptr_array_index( spots, below_qrg ));
+	    printw("%7.1f   %s", centerfrequency,  "============");
+	} else {
+	    show_spot_on_qrg(g_ptr_array_index(spots, below_qrg));
 	}
 	next_spot_position(&bm_y, &bm_x);
     }
 
     /* show spots above QRG */
-    for (i = below_qrg + on_qrg; i < stopindex; i++)
-    {
-	move (bm_y, bm_x);
-	show_spot(g_ptr_array_index( spots, i ));
+    for (i = below_qrg + on_qrg; i < stopindex; i++) {
+	move(bm_y, bm_x);
+	show_spot(g_ptr_array_index(spots, i));
 	next_spot_position(&bm_y, &bm_x);
     }
 
-    attroff (A_BOLD);
+    attroff(A_BOLD);
     move(cury, curx);			/* reset cursor */
 
     refreshp();
@@ -825,19 +843,18 @@ void bandmap_show() {
 
 /** allow control of bandmap features
  */
-void bm_menu()
-{
+void bm_menu() {
     int curx, cury;
     char c = -1;
     int j;
 
-    getyx( stdscr, cury, curx);		/* remember cursor */
+    getyx(stdscr, cury, curx);		/* remember cursor */
 
-    attrset( COLOR_PAIR(C_LOG) | A_STANDOUT );
-    mvprintw( 13, 0, "  Toggle <B>and, <M>ode or <D>upes filter");
+    attrset(COLOR_PAIR(C_LOG) | A_STANDOUT);
+    mvprintw(13, 0, "  Toggle <B>and, <M>ode, <D>upes or <O>nly multi filter");
     printw(" | any other - leave");
 
-    c = toupper( key_get());
+    c = toupper(key_get());
     switch (c) {
 	case 'B':
 	    bm_config.allband = 1 - bm_config.allband;
@@ -850,19 +867,22 @@ void bm_menu()
 	case 'D':
 	    bm_config.showdupes = 1 - bm_config.showdupes;
 	    break;
+
+	case 'O':
+	    bm_config.onlymults = 1 - bm_config.onlymults;
+	    break;
     }
     bandmap_show();		/* refresh display */
 
-    move (13,0);
+    move(13, 0);
     for (j = 0; j < 80; j++)
-	addch (' ');
+	addch(' ');
 
-    move (cury, curx);
+    move(cury, curx);
     refreshp();
 }
 
-spot *copy_spot(spot *data)
-{
+spot *copy_spot(spot *data) {
     spot *result = NULL;
 
     result = g_new(spot, 1);
@@ -873,6 +893,9 @@ spot *copy_spot(spot *data)
     result -> node = data -> node;
     result -> timeout = data -> timeout;
     result -> dupe = data -> dupe;
+    result -> cqzone = data -> cqzone;
+    result -> ctynr = data -> ctynr;
+    result -> pfx = g_strdup(data -> pfx);
 
     return result;
 }
@@ -887,19 +910,17 @@ spot *copy_spot(spot *data)
  * 		or NULL if not found (You have to free the structure
  * 		after use).
  */
-spot *bandmap_lookup(char *partialcall)
-{
+spot *bandmap_lookup(char *partialcall) {
     spot *result = NULL;
 
-    if ((*partialcall != '\0') && (spots->len > 0))
-    {
+    if ((*partialcall != '\0') && (spots->len > 0)) {
 	int i;
 
-	pthread_mutex_lock( &bm_mutex );
+	pthread_mutex_lock(&bm_mutex);
 
 	for (i = 0; i < spots->len; i++) {
 	    spot *data;
-	    data = g_ptr_array_index( spots, i );
+	    data = g_ptr_array_index(spots, i);
 
 	    if (strstr(data->call, partialcall) != NULL) {
 
@@ -910,7 +931,7 @@ spot *bandmap_lookup(char *partialcall)
 	    }
 	}
 
-	pthread_mutex_unlock( &bm_mutex );
+	pthread_mutex_unlock(&bm_mutex);
 
     }
     return result;
@@ -932,22 +953,21 @@ spot *bandmap_lookup(char *partialcall)
  * 		after use).
  */
 
-spot *bandmap_next(unsigned int upwards, unsigned int freq)
-{
+spot *bandmap_next(unsigned int upwards, unsigned int freq) {
     spot *result = NULL;
 
     if (spots->len > 0) {
 	int i;
 
-	pthread_mutex_lock( &bm_mutex );
+	pthread_mutex_lock(&bm_mutex);
 
 	if (upwards) {
 
 	    for (i = 0; i < spots->len; i++) {
 		spot *data;
-		data = g_ptr_array_index( spots, i );
+		data = g_ptr_array_index(spots, i);
 
-		if ((data->freq > freq + TOLERANCE/2) &&
+		if ((data->freq > freq + TOLERANCE / 2) &&
 			(!bm_config.skipdupes || data->dupe == 0)) {
 		    /* copy data into a new Spot structure */
 		    result = copy_spot(data);
@@ -956,11 +976,11 @@ spot *bandmap_next(unsigned int upwards, unsigned int freq)
 		}
 	    }
 	} else {
-	    for (i = spots->len-1; i >= 0; i--) {
+	    for (i = spots->len - 1; i >= 0; i--) {
 		spot *data;
-		data = g_ptr_array_index( spots, i );
+		data = g_ptr_array_index(spots, i);
 
-		if ((data->freq < freq - TOLERANCE/2) &&
+		if ((data->freq < freq - TOLERANCE / 2) &&
 			(!bm_config.skipdupes || data->dupe == 0)) {
 		    /* copy data into a new Spot structure */
 		    result = copy_spot(data);
@@ -969,7 +989,7 @@ spot *bandmap_next(unsigned int upwards, unsigned int freq)
 		}
 	    }
 	}
-	pthread_mutex_unlock( &bm_mutex );
+	pthread_mutex_unlock(&bm_mutex);
 
     }
     return result;
@@ -982,11 +1002,10 @@ spot *bandmap_next(unsigned int upwards, unsigned int freq)
  */
 void str_truncate(char *buffer, char *string, int n) {
     if (strlen(string) > n) {
-	g_strlcpy(buffer, string, n-1);   	/* truncate to n-2 chars */
+	g_strlcpy(buffer, string, n - 1);   	/* truncate to n-2 chars */
 	strcat(buffer, "..");
-    }
-    else {
-	g_strlcpy(buffer, string, n+1); 	/* copy up to n chars */
+    } else {
+	g_strlcpy(buffer, string, n + 1); 	/* copy up to n chars */
     }
 }
 
@@ -995,7 +1014,7 @@ void str_truncate(char *buffer, char *string, int n) {
  * - prepare and return a temporary string from call and number of QTC's
  *   (if any)
  */
-char *qtc_format(char * call) {
+char *qtc_format(char *call) {
     char tcall[15];
     char qtcflag;
     struct t_qtc_store_obj *qtc_temp_ptr;
@@ -1005,9 +1024,8 @@ char *qtc_format(char * call) {
 
     if (qtc_temp_ptr->total <= 0 && qtcflag == '\0') {
 	str_truncate(tcall, call, SPOT_CALL_WIDTH);
-    }
-    else {
-	str_truncate(tcall, call, SPOT_CALL_WIDTH-2);
+    } else {
+	str_truncate(tcall, call, SPOT_CALL_WIDTH - 2);
 	sprintf(tcall + strlen(tcall), " %c", qtcflag);
     }
     return g_strdup(tcall);
@@ -1025,24 +1043,23 @@ void get_spot_on_qrg(char *dest, float freq) {
 
     *dest = '\0';
 
-    if (spots->len > 0)
-    {
+    if (spots->len > 0) {
 	int i;
 
-	pthread_mutex_lock( &bm_mutex );
+	pthread_mutex_lock(&bm_mutex);
 
 	for (i = 0; i < spots->len; i++) {
 	    spot *data;
-	    data = g_ptr_array_index( spots, i );
+	    data = g_ptr_array_index(spots, i);
 
-	    if ((fabs(data->freq - freq*1000) < TOLERANCE) &&
+	    if ((fabs(data->freq - freq * 1000) < TOLERANCE) &&
 		    (!bm_config.skipdupes || data->dupe == 0)) {
 		strcpy(dest, data->call);
 		break;
 	    }
 	}
 
-	pthread_mutex_unlock( &bm_mutex );
+	pthread_mutex_unlock(&bm_mutex);
 
     }
 }
