@@ -22,77 +22,53 @@
 #include <string.h>
 #include <unistd.h>
 
-#include "sendqrg.h"		// Sets HAVE_LIBHAMLIB if enabled
+#include "bands.h"
+#include "sendqrg.h"
 #include "startmsg.h"
+#include "gettxinfo.h"
+#include "bands.h"
+#include "globalvars.h"
 
 
 void send_bandswitch(int trxqrg);
 
-int sendqrg(void)
-{
+/* check if call input field contains a frequency value and switch to it.
+ *
+ */
+int sendqrg(void) {
 
     extern char hiscall[];
     extern int trx_control;
-#ifdef HAVE_LIBHAMLIB
-//extern RIG *my_rig;
-    extern freq_t outfreq;
-#else
-//extern int my_rig;
-    extern int outfreq;
-#endif
 
     float trxqrg;
 
-    if (trx_control != 1)
-	return (0);		/* nothing to do here */
+    if (!trx_control) {
+	return 0;               /* nothing to do here */
+    }
 
     trxqrg = atof(hiscall);
 
-    switch ((int) trxqrg) {
-
-    case 0 ... 1799:{
-	    trxqrg = 0;
-	    break;
-	}
-    case 1800 ...  2000:
-    case 3500 ...  4000:
-    case 7000 ...  7300:
-    case 10100 ... 10150:
-    case 14000 ... 14350:
-    case 18068 ... 18168:
-    case 21000 ... 21450:
-    case 24890 ... 24990:
-    case 28000 ... 29700:
-	{
-#ifdef HAVE_LIBHAMLIB
-	    outfreq = (freq_t) (trxqrg * 1000);
-#else
-	    outfreq = (int) (trxqrg * 1000);
-#endif
-
-	    send_bandswitch((int) trxqrg);
-
-	    break;
-	}
-    default:
-	trxqrg = 0;
+    int bandinx = freq2band((unsigned int)(trxqrg * 1000.0));
 
+    if (bandinx == BANDINDEX_OOB) {
+	return 0;   // not a frequency or out of band
     }
 
-    return ((int)trxqrg);
+    set_outfreq(trxqrg * 1000);
+    send_bandswitch((int) trxqrg);
+
+    return (int) trxqrg;
 }
 
 /**************************************************************************/
 #ifdef HAVE_LIBHAMLIB		//code for Hamlib interface
 
-int init_tlf_rig(void)
-{
+int init_tlf_rig(void) {
     extern RIG *my_rig;
     extern rig_model_t myrig_model;
-    extern freq_t outfreq;
     extern char rigconf[];
     extern int serial_rate;
-    extern char rigportname[];
+    extern char *rigportname;
     extern int debugflag;
     extern unsigned char rigptt;
 
@@ -123,8 +99,7 @@ int init_tlf_rig(void)
 	    rigportname[strlen(rigportname) - 1] = '\0';	// remove '\n'
 	    strncpy(my_rig->state.rigport.pathname, rigportname,
 		    FILPATHLEN);
-	} else
-	{
+	} else {
 	    showmsg("Missing rig port name!");
 	    return (-1);
 	}
@@ -138,8 +113,7 @@ int init_tlf_rig(void)
     if (rigptt & (1 << 0)) {
 	if (caps->ptt_type == RIG_PTT_RIG) {
 	    rigptt |= (1 << 1);		/* bit 1 set--CAT PTT available. */
-	}
-	else {
+	} else {
 	    rigptt = 0;
 	    showmsg("Controlling PTT via hamlib is not supported for that rig!");
 	}
@@ -217,9 +191,9 @@ int init_tlf_rig(void)
 	}
 	sleep(10);
 
-	outfreq = 14000000;	//test set frequency
+	const freq_t testfreq = 14000000;	// test set frequency
 
-	retcode = rig_set_freq(my_rig, RIG_VFO_CURR, outfreq);
+	retcode = rig_set_freq(my_rig, RIG_VFO_CURR, testfreq);
 
 	if (retcode != RIG_OK) {
 	    showmsg("Problem with rig set freq!");
@@ -228,8 +202,6 @@ int init_tlf_rig(void)
 	    showmsg("Rig set freq ok!");
 	}
 
-	outfreq = 0;
-
 	retcode = rig_get_freq(my_rig, RIG_VFO_CURR, &rigfreq);	// read qrg
 
 	if (retcode != RIG_OK) {
@@ -237,18 +209,32 @@ int init_tlf_rig(void)
 	    sleep(1);
 	} else {
 	    shownr("freq =", (int) rigfreq);
+	    if (rigfreq != testfreq) {
+		showmsg("Failed to set rig freq!");
+	    }
 	}
 	sleep(10);
 
     }				// end debug
 
+    switch (trxmode) {
+	case SSBMODE:
+	    set_outfreq(SETSSBMODE);
+	    break;
+	case DIGIMODE:
+	    set_outfreq(SETDIGIMODE);
+	    break;
+	case CWMODE:
+	    set_outfreq(SETCWMODE);
+	    break;
+    }
+
     sleep(1);
     return (0);
 }
 
-int close_tlf_rig(RIG * my_rig)
-{
-    extern char rigportname[];
+int close_tlf_rig(RIG *my_rig) {
+    extern char *rigportname;
 
     rig_close(my_rig);		/* close port */
     rig_cleanup(my_rig);	/* if you care about memory */
